@@ -1,7 +1,7 @@
 __doc__ = """
 This program requires python 3.6 or higher.
 
-Print(functionName.__doc__) to see the
+print(functionName.__doc__) to see the
 
 documentation for the function or usage.
 
@@ -109,7 +109,7 @@ def checkpdbAtoms (pdb_pras,rotamer,mutation,pdb_faspr):
         ' Add Missing Heavy Atoms and Hydrogen Atoms and Assign'+'\n'
         'Secondary Structure by Amide Interactions. Submitted'+'\n')
         log.write('#'*118+'\n')
-        log.write('PRAS 1.0. This is a PRAS-generated log file.'
+        log.write('PRAS 1.0.1 This is a PRAS-generated log file.'
                 ' For your information, fixed atoms (if any) are appended below '+'\n')
         log.write('#'*118+'\n\n')
 
@@ -128,13 +128,13 @@ def checkpdbAtoms (pdb_pras,rotamer,mutation,pdb_faspr):
     """read user's input file to be repaired or analyzed
         but if it is not readable inform the user and
         terminate the program"""
-    try:
-        chains = getChains(pdb_pras,rotamer,mutation,"")
-    except:
-        chains = []
+    #try:
+    chains = getChains(pdb_pras,rotamer,mutation,"")
+    #except:
+        #chains = []
 
-    if not chains:
-        exitError()
+    #if not chains:
+    #    exitError()
 
     for n in range(len(chains)):
         resn,atoms,atmpos,resNo,chain_id = chains[n][0],\
@@ -371,7 +371,7 @@ def checkpdbAtoms (pdb_pras,rotamer,mutation,pdb_faspr):
 
         # add C-terminal O [OXT] if it is missing
         if not 'OXT' in atoms[-1] or 'OC2' in atoms[-1]:
-            atmpos[-1].extend(ctermini(atoms[-1],atmpos[-1]))
+            atmpos[-1].extend(c_termini(atoms[-1],atmpos[-1]))
             atoms[-1].extend(['OXT'])
             repairNotes(resNo[-1], n+1,['OXT'])
 
@@ -384,5 +384,4 @@ def checkpdbAtoms (pdb_pras,rotamer,mutation,pdb_faspr):
                     sg_coord.append(atom_pos[i][1][j])
 
         ter_all.append([resn,atoms,atmpos,resNo,resseq,sg_coord,chain_id])
-    return  ter_all
-
+    return  ter_all
\ No newline at end of file
