@@ -1,7 +1,7 @@
 __doc__ = """
 This program requires python 3.6 or higher.
 
-Print(functionName.__doc__) to see the
+print(functionName.__doc__) to see the
 
 documentation for the function or usage.
 
@@ -181,7 +181,7 @@ def addBackbone(N, CA, C, atmpos, psi):
                 break
     return O
 
-def ctermini(atom,pos):
+def c_termini(atom,pos):
     """
     This function will generate C-ter oxygen if it is missing.
 
