@@ -1,7 +1,7 @@
 __doc__ = """
 This program requires python 3.6 or higher.
 
-Print(functionName.__doc__) to see the
+print(functionName.__doc__) to see the
 
 documentation for the function or usage.
 
